@@ -58,7 +58,8 @@ sub add_chunk {
   my $handle = $self->handle;
   $handle->sysseek(0, SEEK_END);
   $chunk //= '';
-  $handle->syswrite($chunk, length $chunk);
+  croak "Can't write to asset: $!"
+    unless defined $handle->syswrite($chunk, length $chunk);
   return $self;
 }
 
