@@ -23,6 +23,7 @@ has key                => sub { $ENV{MOJO_KEY_FILE} };
 has max_connections    => 5;
 has max_redirects      => sub { $ENV{MOJO_MAX_REDIRECTS} || 0 };
 has name               => 'Mojolicious (Perl)';
+has request_timeout    => 0;
 has transactor => sub { Mojo::UserAgent::Transactor->new };
 has websocket_timeout => 300;
 
@@ -292,13 +293,10 @@ sub _connected {
   $loop->stream($id)->timeout($self->inactivity_timeout);
 
   # Store connection information in transaction
-  my $tx = $self->{connections}->{$id}->{tx};
-  $tx->connection($id);
+  (my $tx = $self->{connections}->{$id}->{tx})->connection($id);
   my $handle = $loop->stream($id)->handle;
-  $tx->local_address($handle->sockhost);
-  $tx->local_port($handle->sockport);
-  $tx->remote_address($handle->peerhost);
-  $tx->remote_port($handle->peerport);
+  $tx->local_address($handle->sockhost)->local_port($handle->sockport);
+  $tx->remote_address($handle->peerhost)->remote_port($handle->peerport);
 
   # Start writing
   weaken $self;
@@ -332,7 +330,7 @@ sub _error {
 sub _events {
   my ($self, $stream, $id) = @_;
   weaken $self;
-  $stream->on(timeout => sub { $self->_error($id, 'Connection timeout.') });
+  $stream->on(timeout => sub { $self->_error($id, 'Inactivity timeout.') });
   $stream->on(close => sub { $self->_handle($id, 1) });
   $stream->on(error => sub { $self->_error($id, pop, 1) });
   $stream->on(read => sub { $self->_read($id, pop) });
@@ -361,8 +359,11 @@ sub _finish {
 sub _handle {
   my ($self, $id, $close) = @_;
 
+  # Request timeout
+  my $c = $self->{connections}->{$id};
+  $self->_loop->drop($c->{timeout}) if $c->{timeout};
+
   # Finish WebSocket
-  my $c   = $self->{connections}->{$id};
   my $old = $c->{tx};
   if ($old && $old->is_websocket) {
     $self->{processing} -= 1;
@@ -421,11 +422,11 @@ sub _redirect {
   return unless my $new = $self->transactor->redirect($old);
 
   # Max redirects
-  my $redirects = $c->{redirects} || 0;
+  my $redirects = delete $c->{redirects} || 0;
   return unless $redirects < $self->max_redirects;
 
   # Follow redirect
-  return 1 unless my $id = $self->_start($new, $c->{cb});
+  return 1 unless my $id = $self->_start($new, delete $c->{cb});
   $self->{connections}->{$id}->{redirects} = $redirects + 1;
   return 1;
 }
@@ -491,6 +492,14 @@ sub _start {
   return unless my $id = $self->_connect($tx, $cb);
   $self->{processing} += 1;
 
+  # Request timeout
+  if (my $t = $self->request_timeout) {
+    weaken $self;
+    my $loop = $self->_loop;
+    $self->{connections}->{$id}->{timeout} =
+      $loop->timer($t => sub { $self->_error($id, 'Request timeout.') });
+  }
+
   return $id;
 }
 
@@ -672,8 +681,8 @@ environment variable.
   my $timeout = $ua->connect_timeout;
   $ua         = $ua->connect_timeout(5);
 
-Maximum amount of time in seconds establishing a connection may take,
-defaults to C<3>.
+Maximum amount of time in seconds establishing a connection may take before
+getting canceled, defaults to C<3>.
 
 =head2 C<cookie_jar>
 
@@ -761,6 +770,20 @@ Value for C<User-Agent> request header, defaults to C<Mojolicious (Perl)>.
 
 Domains that don't require a proxy server to be used.
 
+=head2 C<request_timeout>
+
+  my $timeout = $ua->request_timeout;
+  $ua         = $ua->request_timeout(5);
+
+Maximum amount of time in seconds establishing a connection, sending the
+request and receiving a whole response may take before getting canceled,
+defaults to C<0>. Setting the value to C<0> will allow the user agent to wait
+indefinitely. The timeout will reset for every followed redirect. Note that
+this attribute is EXPERIMENTAL and might change without warning!
+
+  # Total limit of 5 seconds, of which 3 seconds may be spent connecting
+  $ua->max_redirects(0)->connect_timeout(3)->request_timeout(5);
+
 =head2 C<transactor>
 
   my $t = $ua->transactor;
