@@ -199,7 +199,9 @@ sub json_hasnt {
   return $self;
 }
 
+# DEPRECATED in Leaf Fluttering In Wind!
 sub max_redirects {
+  warn "Test::Mojo->max_redirects is DEPRECATED!\n";
   my $self = shift;
   return $self->ua->max_redirects unless @_;
   $self->ua->max_redirects(@_);
@@ -286,8 +288,6 @@ sub status_isnt {
   return $self;
 }
 
-sub test_server { shift->ua->test_server(@_) }
-
 sub text_is {
   my ($self, $selector, $value, $desc) = @_;
   local $Test::Builder::Level = $Test::Builder::Level + 1;
@@ -430,6 +430,8 @@ Current transaction, usually a L<Mojo::Transaction::HTTP> object.
 
 User agent used for testing, defaults to a L<Mojo::UserAgent> object.
 
+  $t->get_ok($t->ua->app_url->userinfo('sri:secr3t')->path('/secrets'));
+
 =head1 METHODS
 
 L<Test::Mojo> inherits all methods from L<Mojo::Base> and implements the
@@ -613,13 +615,6 @@ EXPERIMENTAL and might change without warning!
 Opposite of C<json_has>. Note that this method is EXPERIMENTAL and might
 change without warning!
 
-=head2 C<max_redirects>
-
-  my $max_redirects = $t->max_redirects;
-  $t                = $t->max_redirects(3);
-
-Alias for the L<Mojo::UserAgent/"max_redirects">.
-
 =head2 C<message_is>
 
   $t = $t->message_is('working!');
@@ -699,17 +694,6 @@ Check response status for exact match.
 
 Opposite of C<status_is>.
 
-=head2 C<test_server>
-
-  my $url = $t->test_server;
-  my $url = $t->test_server('http');
-  my $url = $t->test_server('https');
-
-Alias for L<Mojo::UserAgent/"test_server">. Note that this method is
-EXPERIMENTAL and might change without warning!
-
-  $t->get_ok($t->test_server->userinfo('sri:secr3t')->path('/protected'));
-
 =head2 C<text_is>
 
   $t = $t->text_is('div.foo[x=y]' => 'Hello!');
